==> zio-aws-apigatewayv2_2.12-5.17.295.5-sources.jar: zio/aws/apigatewayv2/model/GetRouteRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetRouteRequest(apiId: __string, routeId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest = {
    import GetRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .routeId(routeId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetRouteRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetRouteRequest.wrap(buildAwsValue())
}
object GetRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetRouteRequest =
      zio.aws.apigatewayv2.model.GetRouteRequest(apiId, routeId)
    def apiId: __string
    def routeId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
  ) extends zio.aws.apigatewayv2.model.GetRouteRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val routeId: __string = impl.routeId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
  ): zio.aws.apigatewayv2.model.GetRouteRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.13-5.17.127.1-sources.jar: zio/aws/apigatewayv2/model/GetRouteRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetRouteRequest(apiId: __string, routeId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest = {
    import GetRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .routeId(__string.unwrap(routeId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetRouteRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetRouteRequest.wrap(buildAwsValue())
}
object GetRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetRouteRequest =
      zio.aws.apigatewayv2.model.GetRouteRequest(apiId, routeId)
    def apiId: __string
    def routeId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
  ) extends zio.aws.apigatewayv2.model.GetRouteRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val routeId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.routeId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteRequest
  ): zio.aws.apigatewayv2.model.GetRouteRequest.ReadOnly = new Wrapper(impl)
}
